# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/cbse/ComponentInfo.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.cbse.ComponentState_pb2
import rst.cbse.InputPort_pb2
import rst.cbse.OutputPort_pb2
import rst.timing.Duration_pb2
import rst.timing.Frequency_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/cbse/ComponentInfo.proto',
  package='rst.cbse',
  serialized_pb='\n\x1crst/cbse/ComponentInfo.proto\x12\x08rst.cbse\x1a\x1drst/cbse/ComponentState.proto\x1a\x18rst/cbse/InputPort.proto\x1a\x19rst/cbse/OutputPort.proto\x1a\x19rst/timing/Duration.proto\x1a\x1arst/timing/Frequency.proto\"\xe3\x01\n\rComponentInfo\x12\n\n\x02id\x18\x01 \x02(\t\x12+\n\tlifecycle\x18\x02 \x02(\x0b\x32\x18.rst.cbse.ComponentState\x12#\n\x06inputs\x18\x03 \x02(\x0b\x32\x13.rst.cbse.InputPort\x12%\n\x07outputs\x18\x04 \x02(\x0b\x32\x14.rst.cbse.OutputPort\x12$\n\x06uptime\x18\x05 \x01(\x0b\x32\x14.rst.timing.Duration\x12\'\n\x08\x66reqency\x18\x06 \x01(\x0b\x32\x15.rst.timing.FrequencyB\x13\x42\x11\x43omponentInfoType')




_COMPONENTINFO = _descriptor.Descriptor(
  name='ComponentInfo',
  full_name='rst.cbse.ComponentInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='rst.cbse.ComponentInfo.id', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lifecycle', full_name='rst.cbse.ComponentInfo.lifecycle', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='rst.cbse.ComponentInfo.inputs', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='outputs', full_name='rst.cbse.ComponentInfo.outputs', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='uptime', full_name='rst.cbse.ComponentInfo.uptime', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='freqency', full_name='rst.cbse.ComponentInfo.freqency', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=182,
  serialized_end=409,
)

_COMPONENTINFO.fields_by_name['lifecycle'].message_type = rst.cbse.ComponentState_pb2._COMPONENTSTATE
_COMPONENTINFO.fields_by_name['inputs'].message_type = rst.cbse.InputPort_pb2._INPUTPORT
_COMPONENTINFO.fields_by_name['outputs'].message_type = rst.cbse.OutputPort_pb2._OUTPUTPORT
_COMPONENTINFO.fields_by_name['uptime'].message_type = rst.timing.Duration_pb2._DURATION
_COMPONENTINFO.fields_by_name['freqency'].message_type = rst.timing.Frequency_pb2._FREQUENCY
DESCRIPTOR.message_types_by_name['ComponentInfo'] = _COMPONENTINFO

class ComponentInfo(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _COMPONENTINFO

  # @@protoc_insertion_point(class_scope:rst.cbse.ComponentInfo)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\021ComponentInfoType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/cbse/ComponentState.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/cbse/ComponentState.proto',
  package='rst.cbse',
  serialized_pb='\n\x1drst/cbse/ComponentState.proto\x12\x08rst.cbse\"\xc4\x01\n\x0e\x43omponentState\x12-\n\x05state\x18\x01 \x02(\x0e\x32\x1e.rst.cbse.ComponentState.State\"\x82\x01\n\x05State\x12\x07\n\x03OFF\x10\x01\x12\x06\n\x02ON\x10\x02\x12\n\n\x06PAUSED\x10\x03\x12\r\n\tEXECUTION\x10\x04\x12\x12\n\x0eONLINELEARNING\x10\x05\x12\x13\n\x0fOFFLINELEARNING\x10\x06\x12\t\n\x05RESET\x10\x07\x12\n\n\x06LOADED\x10\x08\x12\r\n\tPERSISTED\x10\tB\x14\x42\x12\x43omponentStateType')



_COMPONENTSTATE_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='rst.cbse.ComponentState.State',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OFF', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ON', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PAUSED', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXECUTION', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ONLINELEARNING', index=4, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OFFLINELEARNING', index=5, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESET', index=6, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOADED', index=7, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PERSISTED', index=8, number=9,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=110,
  serialized_end=240,
)


_COMPONENTSTATE = _descriptor.Descriptor(
  name='ComponentState',
  full_name='rst.cbse.ComponentState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='rst.cbse.ComponentState.state', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _COMPONENTSTATE_STATE,
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=44,
  serialized_end=240,
)

_COMPONENTSTATE.fields_by_name['state'].enum_type = _COMPONENTSTATE_STATE
_COMPONENTSTATE_STATE.containing_type = _COMPONENTSTATE;
DESCRIPTOR.message_types_by_name['ComponentState'] = _COMPONENTSTATE

class ComponentState(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _COMPONENTSTATE

  # @@protoc_insertion_point(class_scope:rst.cbse.ComponentState)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\022ComponentStateType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/monitoring/ProcessCues.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/monitoring/ProcessCues.proto',
  package='rst.monitoring',
  serialized_pb='\n rst/monitoring/ProcessCues.proto\x12\x0erst.monitoring\"\x80\x06\n\x0bProcessCues\x12\x0c\n\x03pid\x18\xe8\x07 \x02(\r\x12\r\n\x04name\x18\xe9\x07 \x01(\x0c\x12\x12\n\thost_name\x18\xea\x07 \x01(\x0c\x12\x15\n\x0c\x63ommand_line\x18\xeb\x07 \x01(\t\x12\x12\n\tunique_id\x18\x94N \x01(\x0c\x12.\n\x04\x63ues\x18\x01 \x03(\x0b\x32 .rst.monitoring.ProcessCues.Cues\x12\x33\n\x07threads\x18\n \x03(\x0b\x32\".rst.monitoring.ProcessCues.Thread\x12-\n\x08\x63hildren\x18\x14 \x03(\x0b\x32\x1b.rst.monitoring.ProcessCues\x1a\xab\x03\n\x04\x43ues\x12\x0f\n\x06source\x18\xe8\x07 \x02(\x0c\x12\r\n\x05utime\x18\x01 \x01(\x04\x12\r\n\x05stime\x18\x02 \x01(\x04\x12\x13\n\x0bnum_threads\x18\x03 \x01(\x03\x12\r\n\x05vsize\x18\x04 \x01(\x04\x12\x0b\n\x03rss\x18\x05 \x01(\x03\x12\x11\n\twall_time\x18\x06 \x01(\x04\x12\x14\n\x0cvirtual_time\x18\x07 \x01(\x04\x12\r\n\x05\x65time\x18\x08 \x01(\x04\x12\x14\n\x0cutime_scaled\x18\t \x01(\x04\x12\x14\n\x0cstime_scaled\x18\n \x01(\x04\x12\x18\n\x10wall_time_scaled\x18\x0b \x01(\x04\x12\x12\n\nstart_time\x18\x0c \x01(\x04\x12\r\n\x05rchar\x18\x1e \x01(\x04\x12\r\n\x05wchar\x18\x1f \x01(\x04\x12\x12\n\nread_bytes\x18  \x01(\x04\x12\x13\n\x0bwrite_bytes\x18! \x01(\x04\x12\x10\n\x08open_fds\x18\x32 \x01(\r\x12\x12\n\nopen_files\x18\x33 \x01(\r\x12\x18\n\x10open_connections\x18< \x01(\r\x12\x16\n\x0ereceived_bytes\x18\x46 \x01(\x04\x12\x12\n\nsent_bytes\x18G \x01(\x04\x1aS\n\x06Thread\x12\x0c\n\x04name\x18\x01 \x01(\x0c\x12\x0b\n\x03tid\x18\x02 \x01(\r\x12.\n\x04\x63ues\x18\n \x03(\x0b\x32 .rst.monitoring.ProcessCues.CuesB\x11\x42\x0fProcessCuesType')




_PROCESSCUES_CUES = _descriptor.Descriptor(
  name='Cues',
  full_name='rst.monitoring.ProcessCues.Cues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='source', full_name='rst.monitoring.ProcessCues.Cues.source', index=0,
      number=1000, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value="",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='utime', full_name='rst.monitoring.ProcessCues.Cues.utime', index=1,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stime', full_name='rst.monitoring.ProcessCues.Cues.stime', index=2,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_threads', full_name='rst.monitoring.ProcessCues.Cues.num_threads', index=3,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vsize', full_name='rst.monitoring.ProcessCues.Cues.vsize', index=4,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rss', full_name='rst.monitoring.ProcessCues.Cues.rss', index=5,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wall_time', full_name='rst.monitoring.ProcessCues.Cues.wall_time', index=6,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='virtual_time', full_name='rst.monitoring.ProcessCues.Cues.virtual_time', index=7,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='etime', full_name='rst.monitoring.ProcessCues.Cues.etime', index=8,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='utime_scaled', full_name='rst.monitoring.ProcessCues.Cues.utime_scaled', index=9,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stime_scaled', full_name='rst.monitoring.ProcessCues.Cues.stime_scaled', index=10,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wall_time_scaled', full_name='rst.monitoring.ProcessCues.Cues.wall_time_scaled', index=11,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='rst.monitoring.ProcessCues.Cues.start_time', index=12,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rchar', full_name='rst.monitoring.ProcessCues.Cues.rchar', index=13,
      number=30, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wchar', full_name='rst.monitoring.ProcessCues.Cues.wchar', index=14,
      number=31, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='read_bytes', full_name='rst.monitoring.ProcessCues.Cues.read_bytes', index=15,
      number=32, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='write_bytes', full_name='rst.monitoring.ProcessCues.Cues.write_bytes', index=16,
      number=33, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='open_fds', full_name='rst.monitoring.ProcessCues.Cues.open_fds', index=17,
      number=50, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='open_files', full_name='rst.monitoring.ProcessCues.Cues.open_files', index=18,
      number=51, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='open_connections', full_name='rst.monitoring.ProcessCues.Cues.open_connections', index=19,
      number=60, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='received_bytes', full_name='rst.monitoring.ProcessCues.Cues.received_bytes', index=20,
      number=70, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sent_bytes', full_name='rst.monitoring.ProcessCues.Cues.sent_bytes', index=21,
      number=71, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=309,
  serialized_end=736,
)

_PROCESSCUES_THREAD = _descriptor.Descriptor(
  name='Thread',
  full_name='rst.monitoring.ProcessCues.Thread',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.monitoring.ProcessCues.Thread.name', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value="",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tid', full_name='rst.monitoring.ProcessCues.Thread.tid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cues', full_name='rst.monitoring.ProcessCues.Thread.cues', index=2,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=738,
  serialized_end=821,
)

_PROCESSCUES = _descriptor.Descriptor(
  name='ProcessCues',
  full_name='rst.monitoring.ProcessCues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pid', full_name='rst.monitoring.ProcessCues.pid', index=0,
      number=1000, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.monitoring.ProcessCues.name', index=1,
      number=1001, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value="",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='host_name', full_name='rst.monitoring.ProcessCues.host_name', index=2,
      number=1002, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value="",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='command_line', full_name='rst.monitoring.ProcessCues.command_line', index=3,
      number=1003, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='unique_id', full_name='rst.monitoring.ProcessCues.unique_id', index=4,
      number=10004, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value="",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cues', full_name='rst.monitoring.ProcessCues.cues', index=5,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='threads', full_name='rst.monitoring.ProcessCues.threads', index=6,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='children', full_name='rst.monitoring.ProcessCues.children', index=7,
      number=20, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_PROCESSCUES_CUES, _PROCESSCUES_THREAD, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=53,
  serialized_end=821,
)

_PROCESSCUES_CUES.containing_type = _PROCESSCUES;
_PROCESSCUES_THREAD.fields_by_name['cues'].message_type = _PROCESSCUES_CUES
_PROCESSCUES_THREAD.containing_type = _PROCESSCUES;
_PROCESSCUES.fields_by_name['cues'].message_type = _PROCESSCUES_CUES
_PROCESSCUES.fields_by_name['threads'].message_type = _PROCESSCUES_THREAD
_PROCESSCUES.fields_by_name['children'].message_type = _PROCESSCUES
DESCRIPTOR.message_types_by_name['ProcessCues'] = _PROCESSCUES

class ProcessCues(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType

  class Cues(_message.Message):
    __metaclass__ = _reflection.GeneratedProtocolMessageType
    DESCRIPTOR = _PROCESSCUES_CUES

    # @@protoc_insertion_point(class_scope:rst.monitoring.ProcessCues.Cues)

  class Thread(_message.Message):
    __metaclass__ = _reflection.GeneratedProtocolMessageType
    DESCRIPTOR = _PROCESSCUES_THREAD

    # @@protoc_insertion_point(class_scope:rst.monitoring.ProcessCues.Thread)
  DESCRIPTOR = _PROCESSCUES

  # @@protoc_insertion_point(class_scope:rst.monitoring.ProcessCues)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\017ProcessCuesType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/devices/flexirob/RobotState.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/devices/flexirob/RobotState.proto',
  package='rst.devices.flexirob',
  serialized_pb='\n%rst/devices/flexirob/RobotState.proto\x12\x14rst.devices.flexirob\"\xdc\x02\n\nRobotState\x12\x45\n\nconnection\x18\x01 \x01(\x0e\x32\x31.rst.devices.flexirob.RobotState.ConnectionStatus\x12=\n\x06motion\x18\x02 \x01(\x0e\x32-.rst.devices.flexirob.RobotState.MotionStatus\x12<\n\x06\x66orces\x18\x03 \x01(\x0e\x32,.rst.devices.flexirob.RobotState.ForceStatus\"4\n\x10\x43onnectionStatus\x12\r\n\tCONNECTED\x10\x01\x12\x11\n\rNOT_CONNECTED\x10\x02\")\n\x0cMotionStatus\x12\r\n\tCONVERGED\x10\x01\x12\n\n\x06MOVING\x10\x02\")\n\x0b\x46orceStatus\x12\x0c\n\x08\x43ONSTANT\x10\x01\x12\x0c\n\x08\x43HANGING\x10\x02\x42\x10\x42\x0eRobotStateType')



_ROBOTSTATE_CONNECTIONSTATUS = _descriptor.EnumDescriptor(
  name='ConnectionStatus',
  full_name='rst.devices.flexirob.RobotState.ConnectionStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONNECTED', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_CONNECTED', index=1, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=274,
  serialized_end=326,
)

_ROBOTSTATE_MOTIONSTATUS = _descriptor.EnumDescriptor(
  name='MotionStatus',
  full_name='rst.devices.flexirob.RobotState.MotionStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONVERGED', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MOVING', index=1, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=328,
  serialized_end=369,
)

_ROBOTSTATE_FORCESTATUS = _descriptor.EnumDescriptor(
  name='ForceStatus',
  full_name='rst.devices.flexirob.RobotState.ForceStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONSTANT', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHANGING', index=1, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=371,
  serialized_end=412,
)


_ROBOTSTATE = _descriptor.Descriptor(
  name='RobotState',
  full_name='rst.devices.flexirob.RobotState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='connection', full_name='rst.devices.flexirob.RobotState.connection', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='motion', full_name='rst.devices.flexirob.RobotState.motion', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='forces', full_name='rst.devices.flexirob.RobotState.forces', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ROBOTSTATE_CONNECTIONSTATUS,
    _ROBOTSTATE_MOTIONSTATUS,
    _ROBOTSTATE_FORCESTATUS,
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=64,
  serialized_end=412,
)

_ROBOTSTATE.fields_by_name['connection'].enum_type = _ROBOTSTATE_CONNECTIONSTATUS
_ROBOTSTATE.fields_by_name['motion'].enum_type = _ROBOTSTATE_MOTIONSTATUS
_ROBOTSTATE.fields_by_name['forces'].enum_type = _ROBOTSTATE_FORCESTATUS
_ROBOTSTATE_CONNECTIONSTATUS.containing_type = _ROBOTSTATE;
_ROBOTSTATE_MOTIONSTATUS.containing_type = _ROBOTSTATE;
_ROBOTSTATE_FORCESTATUS.containing_type = _ROBOTSTATE;
DESCRIPTOR.message_types_by_name['RobotState'] = _ROBOTSTATE

class RobotState(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _ROBOTSTATE

  # @@protoc_insertion_point(class_scope:rst.devices.flexirob.RobotState)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\016RobotStateType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/cbse/Tick.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.timing.Timestamp_pb2
import rst.timing.Duration_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/cbse/Tick.proto',
  package='rst.cbse',
  serialized_pb='\n\x13rst/cbse/Tick.proto\x12\x08rst.cbse\x1a\x1arst/timing/Timestamp.proto\x1a\x19rst/timing/Duration.proto\"\xd3\x01\n\x04Tick\x12\x17\n\x0fsequence_number\x18\x01 \x02(\r\x12(\n\ttimestamp\x18\x02 \x02(\x0b\x32\x15.rst.timing.Timestamp\x12\x30\n\x11virtual_timestamp\x18\x03 \x01(\x0b\x32\x15.rst.timing.Timestamp\x12&\n\x08timestep\x18\x04 \x01(\x0b\x32\x14.rst.timing.Duration\x12.\n\x10virtual_timestep\x18\x05 \x01(\x0b\x32\x14.rst.timing.DurationB\nB\x08TickType')




_TICK = _descriptor.Descriptor(
  name='Tick',
  full_name='rst.cbse.Tick',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sequence_number', full_name='rst.cbse.Tick.sequence_number', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='rst.cbse.Tick.timestamp', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='virtual_timestamp', full_name='rst.cbse.Tick.virtual_timestamp', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestep', full_name='rst.cbse.Tick.timestep', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='virtual_timestep', full_name='rst.cbse.Tick.virtual_timestep', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=89,
  serialized_end=300,
)

_TICK.fields_by_name['timestamp'].message_type = rst.timing.Timestamp_pb2._TIMESTAMP
_TICK.fields_by_name['virtual_timestamp'].message_type = rst.timing.Timestamp_pb2._TIMESTAMP
_TICK.fields_by_name['timestep'].message_type = rst.timing.Duration_pb2._DURATION
_TICK.fields_by_name['virtual_timestep'].message_type = rst.timing.Duration_pb2._DURATION
DESCRIPTOR.message_types_by_name['Tick'] = _TICK

class Tick(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TICK

  # @@protoc_insertion_point(class_scope:rst.cbse.Tick)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\010TickType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/calendar/CalendarUpdate.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.calendar.Event_pb2
import rst.calendar.Todo_pb2
import rst.calendar.TimeZone_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/calendar/CalendarUpdate.proto',
  package='rst.calendar',
  serialized_pb='\n!rst/calendar/CalendarUpdate.proto\x12\x0crst.calendar\x1a\x18rst/calendar/Event.proto\x1a\x17rst/calendar/Todo.proto\x1a\x1brst/calendar/TimeZone.proto\"\xae\x01\n\x0e\x43\x61lendarUpdate\x12)\n\ttimezones\x18\x03 \x03(\x0b\x32\x16.rst.calendar.TimeZone\x12+\n\x0e\x63hanged_events\x18\x04 \x03(\x0b\x32\x13.rst.calendar.Event\x12)\n\rchanged_todos\x18\x05 \x03(\x0b\x32\x12.rst.calendar.Todo\x12\x19\n\x11removed_entry_ids\x18\x06 \x03(\tB\x14\x42\x12\x43\x61lendarUpdateType')




_CALENDARUPDATE = _descriptor.Descriptor(
  name='CalendarUpdate',
  full_name='rst.calendar.CalendarUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timezones', full_name='rst.calendar.CalendarUpdate.timezones', index=0,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='changed_events', full_name='rst.calendar.CalendarUpdate.changed_events', index=1,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='changed_todos', full_name='rst.calendar.CalendarUpdate.changed_todos', index=2,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='removed_entry_ids', full_name='rst.calendar.CalendarUpdate.removed_entry_ids', index=3,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=132,
  serialized_end=306,
)

_CALENDARUPDATE.fields_by_name['timezones'].message_type = rst.calendar.TimeZone_pb2._TIMEZONE
_CALENDARUPDATE.fields_by_name['changed_events'].message_type = rst.calendar.Event_pb2._EVENT
_CALENDARUPDATE.fields_by_name['changed_todos'].message_type = rst.calendar.Todo_pb2._TODO
DESCRIPTOR.message_types_by_name['CalendarUpdate'] = _CALENDARUPDATE

class CalendarUpdate(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _CALENDARUPDATE

  # @@protoc_insertion_point(class_scope:rst.calendar.CalendarUpdate)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\022CalendarUpdateType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/kinematics/JointJerks.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/kinematics/JointJerks.proto',
  package='rst.kinematics',
  serialized_pb='\n\x1frst/kinematics/JointJerks.proto\x12\x0erst.kinematics\"\x1f\n\nJointJerks\x12\x11\n\x05jerks\x18\x01 \x03(\x02\x42\x02\x10\x01\x42\x10\x42\x0eJointJerksType')




_JOINTJERKS = _descriptor.Descriptor(
  name='JointJerks',
  full_name='rst.kinematics.JointJerks',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='jerks', full_name='rst.kinematics.JointJerks.jerks', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), '\020\001')),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=51,
  serialized_end=82,
)

DESCRIPTOR.message_types_by_name['JointJerks'] = _JOINTJERKS

class JointJerks(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _JOINTJERKS

  # @@protoc_insertion_point(class_scope:rst.kinematics.JointJerks)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\016JointJerksType')
_JOINTJERKS.fields_by_name['jerks'].has_options = True
_JOINTJERKS.fields_by_name['jerks']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), '\020\001')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/tracking/TrackedClassifiedRegion3D.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.tracking.TrackingInfo_pb2
import rst.classification.ClassifiedRegion3D_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/tracking/TrackedClassifiedRegion3D.proto',
  package='rst.tracking',
  serialized_pb='\n,rst/tracking/TrackedClassifiedRegion3D.proto\x12\x0crst.tracking\x1a\x1frst/tracking/TrackingInfo.proto\x1a+rst/classification/ClassifiedRegion3D.proto\"}\n\x19TrackedClassifiedRegion3D\x12(\n\x04info\x18\x01 \x02(\x0b\x32\x1a.rst.tracking.TrackingInfo\x12\x36\n\x06region\x18\x02 \x02(\x0b\x32&.rst.classification.ClassifiedRegion3DB\x1f\x42\x1dTrackedClassifiedRegion3DType')




_TRACKEDCLASSIFIEDREGION3D = _descriptor.Descriptor(
  name='TrackedClassifiedRegion3D',
  full_name='rst.tracking.TrackedClassifiedRegion3D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='info', full_name='rst.tracking.TrackedClassifiedRegion3D.info', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='region', full_name='rst.tracking.TrackedClassifiedRegion3D.region', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=140,
  serialized_end=265,
)

_TRACKEDCLASSIFIEDREGION3D.fields_by_name['info'].message_type = rst.tracking.TrackingInfo_pb2._TRACKINGINFO
_TRACKEDCLASSIFIEDREGION3D.fields_by_name['region'].message_type = rst.classification.ClassifiedRegion3D_pb2._CLASSIFIEDREGION3D
DESCRIPTOR.message_types_by_name['TrackedClassifiedRegion3D'] = _TRACKEDCLASSIFIEDREGION3D

class TrackedClassifiedRegion3D(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TRACKEDCLASSIFIEDREGION3D

  # @@protoc_insertion_point(class_scope:rst.tracking.TrackedClassifiedRegion3D)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\035TrackedClassifiedRegion3DType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/robot/JointState.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.kinematics.JointAngles_pb2
import rst.kinematics.JointVelocities_pb2
import rst.dynamics.JointTorques_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/robot/JointState.proto',
  package='rst.robot',
  serialized_pb='\n\x1arst/robot/JointState.proto\x12\trst.robot\x1a rst/kinematics/JointAngles.proto\x1a$rst/kinematics/JointVelocities.proto\x1a\x1frst/dynamics/JointTorques.proto\"\x9b\x01\n\nJointState\x12+\n\x06\x61ngles\x18\x01 \x02(\x0b\x32\x1b.rst.kinematics.JointAngles\x12\x33\n\nvelocities\x18\x02 \x02(\x0b\x32\x1f.rst.kinematics.JointVelocities\x12+\n\x07torques\x18\x03 \x02(\x0b\x32\x1a.rst.dynamics.JointTorquesB\x10\x42\x0eJointStateType')




_JOINTSTATE = _descriptor.Descriptor(
  name='JointState',
  full_name='rst.robot.JointState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='angles', full_name='rst.robot.JointState.angles', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='velocities', full_name='rst.robot.JointState.velocities', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='torques', full_name='rst.robot.JointState.torques', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=147,
  serialized_end=302,
)

_JOINTSTATE.fields_by_name['angles'].message_type = rst.kinematics.JointAngles_pb2._JOINTANGLES
_JOINTSTATE.fields_by_name['velocities'].message_type = rst.kinematics.JointVelocities_pb2._JOINTVELOCITIES
_JOINTSTATE.fields_by_name['torques'].message_type = rst.dynamics.JointTorques_pb2._JOINTTORQUES
DESCRIPTOR.message_types_by_name['JointState'] = _JOINTSTATE

class JointState(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _JOINTSTATE

  # @@protoc_insertion_point(class_scope:rst.robot.JointState)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\016JointStateType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/animation/BinocularHeadGaze.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.geometry.SphericalDirectionFloat_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/animation/BinocularHeadGaze.proto',
  package='rst.animation',
  serialized_pb='\n%rst/animation/BinocularHeadGaze.proto\x12\rrst.animation\x1a*rst/geometry/SphericalDirectionFloat.proto\"\x9a\x01\n\x11\x42inocularHeadGaze\x12\x35\n\x06target\x18\x01 \x02(\x0b\x32%.rst.geometry.SphericalDirectionFloat\x12\x17\n\x0c\x65ye_vergence\x18\x02 \x02(\x02:\x01\x30\x12\x35\n\x06offset\x18\x03 \x02(\x0b\x32%.rst.geometry.SphericalDirectionFloatB\x17\x42\x15\x42inocularHeadGazeType')




_BINOCULARHEADGAZE = _descriptor.Descriptor(
  name='BinocularHeadGaze',
  full_name='rst.animation.BinocularHeadGaze',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='rst.animation.BinocularHeadGaze.target', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='eye_vergence', full_name='rst.animation.BinocularHeadGaze.eye_vergence', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offset', full_name='rst.animation.BinocularHeadGaze.offset', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=101,
  serialized_end=255,
)

_BINOCULARHEADGAZE.fields_by_name['target'].message_type = rst.geometry.SphericalDirectionFloat_pb2._SPHERICALDIRECTIONFLOAT
_BINOCULARHEADGAZE.fields_by_name['offset'].message_type = rst.geometry.SphericalDirectionFloat_pb2._SPHERICALDIRECTIONFLOAT
DESCRIPTOR.message_types_by_name['BinocularHeadGaze'] = _BINOCULARHEADGAZE

class BinocularHeadGaze(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _BINOCULARHEADGAZE

  # @@protoc_insertion_point(class_scope:rst.animation.BinocularHeadGaze)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\025BinocularHeadGazeType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/hri/PersonHypothesis.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.math.Vec2DFloat_pb2
import rst.vision.LocatedFace_pb2
import rst.tracking.TrackingInfo_pb2
import rst.hri.Body_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/hri/PersonHypothesis.proto',
  package='rst.hri',
  serialized_pb='\n\x1erst/hri/PersonHypothesis.proto\x12\x07rst.hri\x1a\x19rst/math/Vec2DFloat.proto\x1a\x1crst/vision/LocatedFace.proto\x1a\x1frst/tracking/TrackingInfo.proto\x1a\x12rst/hri/Body.proto\"\xf0\x03\n\x10PersonHypothesis\x12\x31\n\rtracking_info\x18\x01 \x01(\x0b\x32\x1a.rst.tracking.TrackingInfo\x12%\n\x04\x66\x61\x63\x65\x18\x03 \x01(\x0b\x32\x17.rst.vision.LocatedFace\x12\x1b\n\x04\x62ody\x18\n \x01(\x0b\x32\r.rst.hri.Body\x12/\n\x03\x61ge\x18( \x01(\x0b\x32\".rst.hri.PersonHypothesis.AgeRange\x12\x39\n\x06gender\x18* \x01(\x0e\x32 .rst.hri.PersonHypothesis.Gender:\x07UNKNOWN\x12\x0c\n\x04name\x18, \x01(\t\x12\x14\n\x0chuman_height\x18- \x01(\x02\x12\x44\n\x11\x61ttention_targets\x18\x32 \x03(\x0b\x32).rst.hri.PersonHypothesis.AttentionTarget\x1a,\n\x08\x41geRange\x12\x0f\n\x07\x61ge_min\x18\x01 \x02(\x02\x12\x0f\n\x07\x61ge_max\x18\x02 \x02(\x02\x1a\x34\n\x0f\x41ttentionTarget\x12\x0c\n\x04name\x18\x01 \x02(\x0c\x12\x13\n\x0bprobability\x18\x02 \x02(\x02\"+\n\x06Gender\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04MALE\x10\x01\x12\n\n\x06\x46\x45MALE\x10\x02\x42\x16\x42\x14PersonHypothesisType')



_PERSONHYPOTHESIS_GENDER = _descriptor.EnumDescriptor(
  name='Gender',
  full_name='rst.hri.PersonHypothesis.Gender',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MALE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FEMALE', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=607,
  serialized_end=650,
)


_PERSONHYPOTHESIS_AGERANGE = _descriptor.Descriptor(
  name='AgeRange',
  full_name='rst.hri.PersonHypothesis.AgeRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='age_min', full_name='rst.hri.PersonHypothesis.AgeRange.age_min', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='age_max', full_name='rst.hri.PersonHypothesis.AgeRange.age_max', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=507,
  serialized_end=551,
)

_PERSONHYPOTHESIS_ATTENTIONTARGET = _descriptor.Descriptor(
  name='AttentionTarget',
  full_name='rst.hri.PersonHypothesis.AttentionTarget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.hri.PersonHypothesis.AttentionTarget.name', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value="",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='probability', full_name='rst.hri.PersonHypothesis.AttentionTarget.probability', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=553,
  serialized_end=605,
)

_PERSONHYPOTHESIS = _descriptor.Descriptor(
  name='PersonHypothesis',
  full_name='rst.hri.PersonHypothesis',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tracking_info', full_name='rst.hri.PersonHypothesis.tracking_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='face', full_name='rst.hri.PersonHypothesis.face', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='body', full_name='rst.hri.PersonHypothesis.body', index=2,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='age', full_name='rst.hri.PersonHypothesis.age', index=3,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gender', full_name='rst.hri.PersonHypothesis.gender', index=4,
      number=42, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.hri.PersonHypothesis.name', index=5,
      number=44, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='human_height', full_name='rst.hri.PersonHypothesis.human_height', index=6,
      number=45, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='attention_targets', full_name='rst.hri.PersonHypothesis.attention_targets', index=7,
      number=50, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_PERSONHYPOTHESIS_AGERANGE, _PERSONHYPOTHESIS_ATTENTIONTARGET, ],
  enum_types=[
    _PERSONHYPOTHESIS_GENDER,
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=154,
  serialized_end=650,
)

_PERSONHYPOTHESIS_AGERANGE.containing_type = _PERSONHYPOTHESIS;
_PERSONHYPOTHESIS_ATTENTIONTARGET.containing_type = _PERSONHYPOTHESIS;
_PERSONHYPOTHESIS.fields_by_name['tracking_info'].message_type = rst.tracking.TrackingInfo_pb2._TRACKINGINFO
_PERSONHYPOTHESIS.fields_by_name['face'].message_type = rst.vision.LocatedFace_pb2._LOCATEDFACE
_PERSONHYPOTHESIS.fields_by_name['body'].message_type = rst.hri.Body_pb2._BODY
_PERSONHYPOTHESIS.fields_by_name['age'].message_type = _PERSONHYPOTHESIS_AGERANGE
_PERSONHYPOTHESIS.fields_by_name['gender'].enum_type = _PERSONHYPOTHESIS_GENDER
_PERSONHYPOTHESIS.fields_by_name['attention_targets'].message_type = _PERSONHYPOTHESIS_ATTENTIONTARGET
_PERSONHYPOTHESIS_GENDER.containing_type = _PERSONHYPOTHESIS;
DESCRIPTOR.message_types_by_name['PersonHypothesis'] = _PERSONHYPOTHESIS

class PersonHypothesis(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType

  class AgeRange(_message.Message):
    __metaclass__ = _reflection.GeneratedProtocolMessageType
    DESCRIPTOR = _PERSONHYPOTHESIS_AGERANGE

    # @@protoc_insertion_point(class_scope:rst.hri.PersonHypothesis.AgeRange)

  class AttentionTarget(_message.Message):
    __metaclass__ = _reflection.GeneratedProtocolMessageType
    DESCRIPTOR = _PERSONHYPOTHESIS_ATTENTIONTARGET

    # @@protoc_insertion_point(class_scope:rst.hri.PersonHypothesis.AttentionTarget)
  DESCRIPTOR = _PERSONHYPOTHESIS

  # @@protoc_insertion_point(class_scope:rst.hri.PersonHypothesis)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\024PersonHypothesisType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/tts/TextToSpeechInstruction.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.tts.Prosody_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/tts/TextToSpeechInstruction.proto',
  package='rst.tts',
  serialized_pb='\n%rst/tts/TextToSpeechInstruction.proto\x12\x07rst.tts\x1a\x15rst/tts/Prosody.proto\"\xd7\x01\n\x17TextToSpeechInstruction\x12\x0c\n\x04text\x18\x01 \x01(\t\x12!\n\x07prosody\x18\x02 \x01(\x0b\x32\x10.rst.tts.Prosody\x12N\n\x0fplayback_option\x18\x03 \x01(\x0e\x32/.rst.tts.TextToSpeechInstruction.PlaybackOption:\x04PLAY\";\n\x0ePlaybackOption\x12\x08\n\x04PLAY\x10\x00\x12\x08\n\x04STOP\x10\x01\x12\t\n\x05PAUSE\x10\x02\x12\n\n\x06RESUME\x10\x03\x42\x1d\x42\x1bTextToSpeechInstructionType')



_TEXTTOSPEECHINSTRUCTION_PLAYBACKOPTION = _descriptor.EnumDescriptor(
  name='PlaybackOption',
  full_name='rst.tts.TextToSpeechInstruction.PlaybackOption',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PLAY', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STOP', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PAUSE', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESUME', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=230,
  serialized_end=289,
)


_TEXTTOSPEECHINSTRUCTION = _descriptor.Descriptor(
  name='TextToSpeechInstruction',
  full_name='rst.tts.TextToSpeechInstruction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='rst.tts.TextToSpeechInstruction.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='prosody', full_name='rst.tts.TextToSpeechInstruction.prosody', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='playback_option', full_name='rst.tts.TextToSpeechInstruction.playback_option', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TEXTTOSPEECHINSTRUCTION_PLAYBACKOPTION,
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=74,
  serialized_end=289,
)

_TEXTTOSPEECHINSTRUCTION.fields_by_name['prosody'].message_type = rst.tts.Prosody_pb2._PROSODY
_TEXTTOSPEECHINSTRUCTION.fields_by_name['playback_option'].enum_type = _TEXTTOSPEECHINSTRUCTION_PLAYBACKOPTION
_TEXTTOSPEECHINSTRUCTION_PLAYBACKOPTION.containing_type = _TEXTTOSPEECHINSTRUCTION;
DESCRIPTOR.message_types_by_name['TextToSpeechInstruction'] = _TEXTTOSPEECHINSTRUCTION

class TextToSpeechInstruction(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TEXTTOSPEECHINSTRUCTION

  # @@protoc_insertion_point(class_scope:rst.tts.TextToSpeechInstruction)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\033TextToSpeechInstructionType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/vision/FaceLandmarks.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.math.Vec2DInt_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/vision/FaceLandmarks.proto',
  package='rst.vision',
  serialized_pb='\n\x1erst/vision/FaceLandmarks.proto\x12\nrst.vision\x1a\x17rst/math/Vec2DInt.proto\"\xe6\x02\n\rFaceLandmarks\x12\x1f\n\x03jaw\x18\x01 \x03(\x0b\x32\x12.rst.math.Vec2DInt\x12 \n\x04nose\x18\x02 \x03(\x0b\x32\x12.rst.math.Vec2DInt\x12&\n\nnose_wings\x18\x03 \x03(\x0b\x32\x12.rst.math.Vec2DInt\x12&\n\nright_brow\x18\x04 \x03(\x0b\x32\x12.rst.math.Vec2DInt\x12%\n\tleft_brow\x18\x05 \x03(\x0b\x32\x12.rst.math.Vec2DInt\x12%\n\tright_eye\x18\x06 \x03(\x0b\x32\x12.rst.math.Vec2DInt\x12$\n\x08left_eye\x18\x07 \x03(\x0b\x32\x12.rst.math.Vec2DInt\x12&\n\nouter_lips\x18\x08 \x03(\x0b\x32\x12.rst.math.Vec2DInt\x12&\n\ninner_lips\x18\t \x03(\x0b\x32\x12.rst.math.Vec2DIntB\x13\x42\x11\x46\x61\x63\x65LandmarksType')




_FACELANDMARKS = _descriptor.Descriptor(
  name='FaceLandmarks',
  full_name='rst.vision.FaceLandmarks',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='jaw', full_name='rst.vision.FaceLandmarks.jaw', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='nose', full_name='rst.vision.FaceLandmarks.nose', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='nose_wings', full_name='rst.vision.FaceLandmarks.nose_wings', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='right_brow', full_name='rst.vision.FaceLandmarks.right_brow', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='left_brow', full_name='rst.vision.FaceLandmarks.left_brow', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='right_eye', full_name='rst.vision.FaceLandmarks.right_eye', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='left_eye', full_name='rst.vision.FaceLandmarks.left_eye', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='outer_lips', full_name='rst.vision.FaceLandmarks.outer_lips', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='inner_lips', full_name='rst.vision.FaceLandmarks.inner_lips', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=72,
  serialized_end=430,
)

_FACELANDMARKS.fields_by_name['jaw'].message_type = rst.math.Vec2DInt_pb2._VEC2DINT
_FACELANDMARKS.fields_by_name['nose'].message_type = rst.math.Vec2DInt_pb2._VEC2DINT
_FACELANDMARKS.fields_by_name['nose_wings'].message_type = rst.math.Vec2DInt_pb2._VEC2DINT
_FACELANDMARKS.fields_by_name['right_brow'].message_type = rst.math.Vec2DInt_pb2._VEC2DINT
_FACELANDMARKS.fields_by_name['left_brow'].message_type = rst.math.Vec2DInt_pb2._VEC2DINT
_FACELANDMARKS.fields_by_name['right_eye'].message_type = rst.math.Vec2DInt_pb2._VEC2DINT
_FACELANDMARKS.fields_by_name['left_eye'].message_type = rst.math.Vec2DInt_pb2._VEC2DINT
_FACELANDMARKS.fields_by_name['outer_lips'].message_type = rst.math.Vec2DInt_pb2._VEC2DINT
_FACELANDMARKS.fields_by_name['inner_lips'].message_type = rst.math.Vec2DInt_pb2._VEC2DINT
DESCRIPTOR.message_types_by_name['FaceLandmarks'] = _FACELANDMARKS

class FaceLandmarks(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _FACELANDMARKS

  # @@protoc_insertion_point(class_scope:rst.vision.FaceLandmarks)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\021FaceLandmarksType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/cogimon/ModelComponentConfig.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/cogimon/ModelComponentConfig.proto',
  package='rst.cogimon',
  serialized_pb='\n&rst/cogimon/ModelComponentConfig.proto\x12\x0brst.cogimon\"\x85\x01\n\x14ModelComponentConfig\x12\x16\n\x0e\x63omponent_name\x18\x01 \x02(\t\x12\x16\n\x0e\x63omponent_type\x18\x02 \x02(\t\x12\x19\n\x11\x63omponent_package\x18\x03 \x02(\t\x12\x12\n\nmodel_name\x18\x04 \x02(\t\x12\x0e\n\x06script\x18\x05 \x01(\tB\x1a\x42\x18ModelComponentConfigType')




_MODELCOMPONENTCONFIG = _descriptor.Descriptor(
  name='ModelComponentConfig',
  full_name='rst.cogimon.ModelComponentConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='component_name', full_name='rst.cogimon.ModelComponentConfig.component_name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='component_type', full_name='rst.cogimon.ModelComponentConfig.component_type', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='component_package', full_name='rst.cogimon.ModelComponentConfig.component_package', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='model_name', full_name='rst.cogimon.ModelComponentConfig.model_name', index=3,
      number=4, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='script', full_name='rst.cogimon.ModelComponentConfig.script', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=56,
  serialized_end=189,
)

DESCRIPTOR.message_types_by_name['ModelComponentConfig'] = _MODELCOMPONENTCONFIG

class ModelComponentConfig(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _MODELCOMPONENTCONFIG

  # @@protoc_insertion_point(class_scope:rst.cogimon.ModelComponentConfig)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\030ModelComponentConfigType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/vision/HeadObject.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.geometry.BoundingBox_pb2
import rst.tracking.TrackingInfo_pb2
import rst.vision.Face_pb2
import rst.math.Vec3DFloat_pb2
import rst.classification.ClassificationResult_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/vision/HeadObject.proto',
  package='rst.vision',
  serialized_pb='\n\x1brst/vision/HeadObject.proto\x12\nrst.vision\x1a\x1erst/geometry/BoundingBox.proto\x1a\x1frst/tracking/TrackingInfo.proto\x1a\x15rst/vision/Face.proto\x1a\x19rst/math/Vec3DFloat.proto\x1a-rst/classification/ClassificationResult.proto\"\x87\x04\n\nHeadObject\x12\x31\n\rtracking_info\x18\x01 \x01(\x0b\x32\x1a.rst.tracking.TrackingInfo\x12)\n\x06region\x18\x02 \x01(\x0b\x32\x19.rst.geometry.BoundingBox\x12&\n\x08position\x18\x03 \x01(\x0b\x32\x14.rst.math.Vec3DFloat\x12\"\n\x04pose\x18\x04 \x01(\x0b\x32\x14.rst.math.Vec3DFloat\x12\x31\n\x05\x66\x61\x63\x65s\x18\x06 \x03(\x0b\x32\".rst.vision.HeadObject.LabeledFace\x12\x1c\n\x14speaking_probability\x18\x07 \x01(\x02\x12\x13\n\x0bvfoa_target\x18\x08 \x01(\x0c\x12:\n\x08identity\x18\t \x01(\x0b\x32(.rst.classification.ClassificationResult\x12\x38\n\x06gender\x18\n \x01(\x0b\x32(.rst.classification.ClassificationResult\x12\x35\n\x03\x61ge\x18\x0b \x01(\x0b\x32(.rst.classification.ClassificationResult\x1a<\n\x0bLabeledFace\x12\r\n\x05label\x18\x01 \x02(\x0c\x12\x1e\n\x04\x66\x61\x63\x65\x18\x02 \x02(\x0b\x32\x10.rst.vision.FaceB\x10\x42\x0eHeadObjectType')




_HEADOBJECT_LABELEDFACE = _descriptor.Descriptor(
  name='LabeledFace',
  full_name='rst.vision.HeadObject.LabeledFace',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='rst.vision.HeadObject.LabeledFace.label', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value="",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='face', full_name='rst.vision.HeadObject.LabeledFace.face', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=665,
  serialized_end=725,
)

_HEADOBJECT = _descriptor.Descriptor(
  name='HeadObject',
  full_name='rst.vision.HeadObject',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tracking_info', full_name='rst.vision.HeadObject.tracking_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='region', full_name='rst.vision.HeadObject.region', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='position', full_name='rst.vision.HeadObject.position', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pose', full_name='rst.vision.HeadObject.pose', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='faces', full_name='rst.vision.HeadObject.faces', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='speaking_probability', full_name='rst.vision.HeadObject.speaking_probability', index=5,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vfoa_target', full_name='rst.vision.HeadObject.vfoa_target', index=6,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value="",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='identity', full_name='rst.vision.HeadObject.identity', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gender', full_name='rst.vision.HeadObject.gender', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='age', full_name='rst.vision.HeadObject.age', index=9,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_HEADOBJECT_LABELEDFACE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=206,
  serialized_end=725,
)

_HEADOBJECT_LABELEDFACE.fields_by_name['face'].message_type = rst.vision.Face_pb2._FACE
_HEADOBJECT_LABELEDFACE.containing_type = _HEADOBJECT;
_HEADOBJECT.fields_by_name['tracking_info'].message_type = rst.tracking.TrackingInfo_pb2._TRACKINGINFO
_HEADOBJECT.fields_by_name['region'].message_type = rst.geometry.BoundingBox_pb2._BOUNDINGBOX
_HEADOBJECT.fields_by_name['position'].message_type = rst.math.Vec3DFloat_pb2._VEC3DFLOAT
_HEADOBJECT.fields_by_name['pose'].message_type = rst.math.Vec3DFloat_pb2._VEC3DFLOAT
_HEADOBJECT.fields_by_name['faces'].message_type = _HEADOBJECT_LABELEDFACE
_HEADOBJECT.fields_by_name['identity'].message_type = rst.classification.ClassificationResult_pb2._CLASSIFICATIONRESULT
_HEADOBJECT.fields_by_name['gender'].message_type = rst.classification.ClassificationResult_pb2._CLASSIFICATIONRESULT
_HEADOBJECT.fields_by_name['age'].message_type = rst.classification.ClassificationResult_pb2._CLASSIFICATIONRESULT
DESCRIPTOR.message_types_by_name['HeadObject'] = _HEADOBJECT

class HeadObject(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType

  class LabeledFace(_message.Message):
    __metaclass__ = _reflection.GeneratedProtocolMessageType
    DESCRIPTOR = _HEADOBJECT_LABELEDFACE

    # @@protoc_insertion_point(class_scope:rst.vision.HeadObject.LabeledFace)
  DESCRIPTOR = _HEADOBJECT

  # @@protoc_insertion_point(class_scope:rst.vision.HeadObject)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\016HeadObjectType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/monitoring/ProcessAnomaly.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/monitoring/ProcessAnomaly.proto',
  package='rst.monitoring',
  serialized_pb='\n#rst/monitoring/ProcessAnomaly.proto\x12\x0erst.monitoring\"R\n\x0eProcessAnomaly\x12\x0c\n\x03pid\x18\xe8\x07 \x02(\r\x12\r\n\x04name\x18\xe9\x07 \x01(\x0c\x12\x12\n\thost_name\x18\xea\x07 \x01(\x0c\x12\x0f\n\x07reasons\x18\x01 \x03(\tB\x14\x42\x12ProcessAnomalyType')




_PROCESSANOMALY = _descriptor.Descriptor(
  name='ProcessAnomaly',
  full_name='rst.monitoring.ProcessAnomaly',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pid', full_name='rst.monitoring.ProcessAnomaly.pid', index=0,
      number=1000, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.monitoring.ProcessAnomaly.name', index=1,
      number=1001, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value="",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='host_name', full_name='rst.monitoring.ProcessAnomaly.host_name', index=2,
      number=1002, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value="",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reasons', full_name='rst.monitoring.ProcessAnomaly.reasons', index=3,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=55,
  serialized_end=137,
)

DESCRIPTOR.message_types_by_name['ProcessAnomaly'] = _PROCESSANOMALY

class ProcessAnomaly(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _PROCESSANOMALY

  # @@protoc_insertion_point(class_scope:rst.monitoring.ProcessAnomaly)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\022ProcessAnomalyType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/cbse/InputPort.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/cbse/InputPort.proto',
  package='rst.cbse',
  serialized_pb='\n\x18rst/cbse/InputPort.proto\x12\x08rst.cbse\"?\n\tInputPort\x12\r\n\x05scope\x18\x01 \x02(\t\x12\x12\n\nbuffersize\x18\x02 \x01(\x04\x12\x0f\n\x07\x66illing\x18\x03 \x01(\x04\x42\x0f\x42\rInputPortType')




_INPUTPORT = _descriptor.Descriptor(
  name='InputPort',
  full_name='rst.cbse.InputPort',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='scope', full_name='rst.cbse.InputPort.scope', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='buffersize', full_name='rst.cbse.InputPort.buffersize', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filling', full_name='rst.cbse.InputPort.filling', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=38,
  serialized_end=101,
)

DESCRIPTOR.message_types_by_name['InputPort'] = _INPUTPORT

class InputPort(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _INPUTPORT

  # @@protoc_insertion_point(class_scope:rst.cbse.InputPort)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\rInputPortType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/hri/PersonHypotheses.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.hri.PersonHypothesis_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/hri/PersonHypotheses.proto',
  package='rst.hri',
  serialized_pb='\n\x1erst/hri/PersonHypotheses.proto\x12\x07rst.hri\x1a\x1erst/hri/PersonHypothesis.proto\">\n\x10PersonHypotheses\x12*\n\x07persons\x18\x01 \x03(\x0b\x32\x19.rst.hri.PersonHypothesisB\x16\x42\x14PersonHypothesesType')




_PERSONHYPOTHESES = _descriptor.Descriptor(
  name='PersonHypotheses',
  full_name='rst.hri.PersonHypotheses',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='persons', full_name='rst.hri.PersonHypotheses.persons', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=75,
  serialized_end=137,
)

_PERSONHYPOTHESES.fields_by_name['persons'].message_type = rst.hri.PersonHypothesis_pb2._PERSONHYPOTHESIS
DESCRIPTOR.message_types_by_name['PersonHypotheses'] = _PERSONHYPOTHESES

class PersonHypotheses(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _PERSONHYPOTHESES

  # @@protoc_insertion_point(class_scope:rst.hri.PersonHypotheses)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\024PersonHypothesesType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/robot/Weights.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/robot/Weights.proto',
  package='rst.robot',
  serialized_pb='\n\x17rst/robot/Weights.proto\x12\trst.robot\"\x1e\n\x07Weights\x12\x13\n\x07weights\x18\x01 \x03(\x02\x42\x02\x10\x01\x42\rB\x0bWeightsType')




_WEIGHTS = _descriptor.Descriptor(
  name='Weights',
  full_name='rst.robot.Weights',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='weights', full_name='rst.robot.Weights.weights', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), '\020\001')),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=38,
  serialized_end=68,
)

DESCRIPTOR.message_types_by_name['Weights'] = _WEIGHTS

class Weights(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _WEIGHTS

  # @@protoc_insertion_point(class_scope:rst.robot.Weights)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\013WeightsType')
_WEIGHTS.fields_by_name['weights'].has_options = True
_WEIGHTS.fields_by_name['weights']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), '\020\001')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/tracking/TrackedPolygonalPatch3D.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.tracking.TrackingInfo_pb2
import rst.geometry.PolygonalPatch3D_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/tracking/TrackedPolygonalPatch3D.proto',
  package='rst.tracking',
  serialized_pb='\n*rst/tracking/TrackedPolygonalPatch3D.proto\x12\x0crst.tracking\x1a\x1frst/tracking/TrackingInfo.proto\x1a#rst/geometry/PolygonalPatch3D.proto\"r\n\x17TrackedPolygonalPatch3D\x12(\n\x04info\x18\x01 \x02(\x0b\x32\x1a.rst.tracking.TrackingInfo\x12-\n\x05patch\x18\x02 \x02(\x0b\x32\x1e.rst.geometry.PolygonalPatch3DB\x1d\x42\x1bTrackedPolygonalPatch3DType')




_TRACKEDPOLYGONALPATCH3D = _descriptor.Descriptor(
  name='TrackedPolygonalPatch3D',
  full_name='rst.tracking.TrackedPolygonalPatch3D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='info', full_name='rst.tracking.TrackedPolygonalPatch3D.info', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='patch', full_name='rst.tracking.TrackedPolygonalPatch3D.patch', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=130,
  serialized_end=244,
)

_TRACKEDPOLYGONALPATCH3D.fields_by_name['info'].message_type = rst.tracking.TrackingInfo_pb2._TRACKINGINFO
_TRACKEDPOLYGONALPATCH3D.fields_by_name['patch'].message_type = rst.geometry.PolygonalPatch3D_pb2._POLYGONALPATCH3D
DESCRIPTOR.message_types_by_name['TrackedPolygonalPatch3D'] = _TRACKEDPOLYGONALPATCH3D

class TrackedPolygonalPatch3D(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TRACKEDPOLYGONALPATCH3D

  # @@protoc_insertion_point(class_scope:rst.tracking.TrackedPolygonalPatch3D)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\033TrackedPolygonalPatch3DType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/classification/ClassificationResults.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.classification.ClassificationResult_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/classification/ClassificationResults.proto',
  package='rst.classification',
  serialized_pb='\n.rst/classification/ClassificationResults.proto\x12\x12rst.classification\x1a-rst/classification/ClassificationResult.proto\"R\n\x15\x43lassificationResults\x12\x39\n\x07\x63lasses\x18\x01 \x03(\x0b\x32(.rst.classification.ClassificationResultB\x1b\x42\x19\x43lassificationResultsType')




_CLASSIFICATIONRESULTS = _descriptor.Descriptor(
  name='ClassificationResults',
  full_name='rst.classification.ClassificationResults',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='classes', full_name='rst.classification.ClassificationResults.classes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=117,
  serialized_end=199,
)

_CLASSIFICATIONRESULTS.fields_by_name['classes'].message_type = rst.classification.ClassificationResult_pb2._CLASSIFICATIONRESULT
DESCRIPTOR.message_types_by_name['ClassificationResults'] = _CLASSIFICATIONRESULTS

class ClassificationResults(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _CLASSIFICATIONRESULTS

  # @@protoc_insertion_point(class_scope:rst.classification.ClassificationResults)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\031ClassificationResultsType')
# @@protoc_insertion_point(module_scope)
